OiRA

Help

1. Undirbúningur
3. Greining + Mat
4. Aðgerðaáætlun
5. Skýrsla
6. Staða 0%

# Skýrsla

Nú er aðgerðaáætlun lokið og hægt er að vista skýrslu með öllum niðurstöðum. Hægt er að bæta við athugasemdum í skýrsluna. Setjið þær í reitinn hér fyrir neðan.

Vista og halda áfram

Scroll to top
Back

## report.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More